Data<- read.csv("/Desktop_2016/BecA_ILRI/Metagenomics/TLevel_4.csv")
Datab<- read.csv("/Desktop_2016/BecA_ILRI/Metagenomics/TLevel_4.csv", row.names=1)
Time_AMOVA <- read.csv("/Desktop_2016/Rachel/Time_AMOVA.csv")
Treatment_AMOVA <- read.csv("/Desktop_2016/Rachel/Treatment_AMOVA.csv")

#Install packages
install.packages("vegan")
install.packages("BiodiversityR")
install.packages("ape")
install.packages("ade4")
install.packages("pegas")
install.packages("scatterplot3d")
install.packages("gplots")

#Call libraries

library(vegan)
library(BiodiversityR)
library(ape)
library(ade4)
library(pegas)
library(scatterplot3d)
library(gplots)


#Conduct principal component analysis
KK=prcomp(Data[,-1],center=TRUE, scale=TRUE)

#Show the % variations PC 

summary(KK)

#Show the scores

KK$x

#Show eigenvalues
KK$sdev

#Show the eigenvectors
KK$rotation

#Plot 2D plot of scores
quartz(height=10, width=10, pointsize=12)
par(mfrow=c(3, 1), cex=0.6, mar=c(4, 4, 4, 2), mex=0.8)
plot(x = KK$x[,1], y = KK$x[,2], type = "n", pch=17, xlab = "PC1 (39.5%)", ylab = "PC2 (16.3%)")
abline(h = 0, lty = 1, lwd = 1)  
abline(v = 0, lty = 1, lwd = 1)  
text(x = KK$x[,1], y = KK$x[,2], labels = Data$Sample)  

#Put the scores in an object called G to plot a 3D plot

G<-data.frame(KK$x)

s3d<-scatterplot3d (G[,1:3], type="n", pch=17, xlab= "PC1 (39.5%)", ylab="PC2 (16.3%)", zlab="PC3 (9.0%)", main="3D scatter plot") 
text(s3d$xyz.convert(G[, 1:3]), labels = Data$Sample)

#Principal Coordinate analysis
#PcoA
CON<-vegdist(Datab, method="euclidean")
PCOA_Con<-pcoa(CON, rn=NULL)
P<-data.frame(PCOA_Con[4])
 
s3d<-scatterplot3d (P[,1:3], type="n", pch=17, xlab= "PC1 (88.4%)", ylab="PC2 (9.3%)", zlab="PC3 (1.0%)", main="3D scatter plot") 
text(s3d$xyz.convert(P[, 1:3]), labels = rownames(P))

#AMOVA
Time_AMOVA_T0 <- Time_AMOVA[1:16,]
Time_AMOVA_T3 <- Time_AMOVA[17:32,]
Time_AMOVA_T5 <- Time_AMOVA[33:48,]
Time_AMOVA_T30 <- Time_AMOVA[49:64,]

Time_AMOVA_T0 <- Time_AMOVA_T0[,-2]
Time_AMOVA_T3 <- Time_AMOVA_T3[,-2] 
Time_AMOVA_T5 <- Time_AMOVA_T5[,-2]
Time_AMOVA_T30 <- Time_AMOVA_T30[,-2]

g <- factor(c(rep("A", 4), rep("B", 4),rep("C", 4),rep("D", 4)))
#distance
dT0<-dist(Time_AMOVA_T0[,-1])

#AMOVA Time 0
AMOVA_T0<-amova(dT0 ~ g, nperm = 1000)

#distance
dT3<-dist(Time_AMOVA_T3[,-1])

#AMOVA Time 3
AMOVA_T3<-amova(dT3 ~ g, nperm = 1000)

#AMOVA Time 5
#distance
dT5<-dist(Time_AMOVA_T5[,-1])

#AMOVA Time 5
AMOVA_T5<-amova(dT5 ~ g, nperm = 1000)


#AMOVA Time 30
#distance
dT30<-dist(Time_AMOVA_T30[,-1])

#AMOVA Time 30
AMOVA_T30<-amova(dT30 ~ g, nperm = 1000)


#Treatment
Treatment_AMOVA_T0 <- Treatment_AMOVA[1:16,]
Treatment_AMOVA_T3 <- Treatment_AMOVA[17:32,]
Treatment_AMOVA_T5 <- Treatment_AMOVA[33:48,]
Treatment_AMOVA_T30 <- Treatment_AMOVA[49:64,]

Treatment_AMOVA_T0 <- Treatment_AMOVA_T0[,-1]
Treatment_AMOVA_T3 <- Treatment_AMOVA_T3[,-1] 
Treatment_AMOVA_T5 <- Treatment_AMOVA_T5[,-1]
Treatment_AMOVA_T30 <- Treatment_AMOVA_T30[,-1]

g <- factor(c(rep("0", 4), rep("3", 4),rep("5", 4),rep("30", 4)))

#distance
dT0<-dist(Treatment_AMOVA_T0[,-1])
#AMOVA A
AMOVA_A<-amova(dT0 ~ g, nperm = 1000)

#distance
dT3<-dist(Treatment_AMOVA_T3[,-1])

#AMOVA B
AMOVA_B<-amova(dT3 ~ g, nperm = 1000)

#AMOVA C
#distance
dT5<-dist(Treatment_AMOVA_T5[,-1])

#AMOVA C
AMOVA_C<-amova(dT5 ~ g, nperm = 1000)

#Diversity Shannon and Simpson
#Shannon
SIM<-diversity(Data[,-1],index="shannon")
SIM

#Simpson diversity
invsimp <- diversity(Data[,-1], "inv")
invsimp

#Richness all groups
All_Grp<-specnumber(Data[,-1], MARGIN=2)

#Richeness for each group
Grp_1<-specnumber(Data[1,-1], MARGIN=2)
Grp_2<-specnumber(Data[1,-1], MARGIN=2)


#OTUs in a Graph format

colnames(Data)<- colnames(Data)
 rnames <- Data[,1]
 
 
 mat_data <- data.matrix(Data[,2:ncol(Data)])
 
 rownames(mat_data) <- rnames

 my_palette <- colorRampPalette(c("red", "yellow", "green"))(n = 100)
 
col_breaks = c(seq(-1,0,length=300), # for red
seq(0,0.8,length=100), # for yellow
seq(0.8,1,length=100)) # for green

heatmap.2(mat_data,
  cellnote = mat_data,  # same data set for cell labels
  main = "Numbers of OTUs for bacteria in each Group", # heat map title
  notecol="black",      # change font color of cell labels to black
  density.info="none",  # turns off density plot inside color legend
  trace="none",         # turns off trace lines inside the heat map
  margins =c(10,15),     # widens margins around plot
  col=my_palette,       # use on color palette defined earlier 
 # breaks=col_breaks,    # enable color transition at specified limits
  dendrogram="none",     # only draw a row dendrogram
  Colv="NA")            # turn off column clustering 
  




